<img align=center src=./logo.png length=80 width = 400>


> This library is a collection of popular Addons and patches for pyrogram/Kurigram.
> Currently, Pykeyboard and Pyrogram-patch have been added. You're welcome to add more.

# Installation

```shell
pip install kurigram-addons
```

# Usage

Please refer to specific readme.md for each addon.
